Cost-complexity Pruning of an Rpart Object
prune.rpart.RdDetermines a nested sequence of subtrees of the supplied rpart object
by recursively snipping off the least important splits, based on the
complexity parameter (cp).
Arguments
- tree
fitted model object of class
rpart. This is assumed to be the result of some function that produces an object with the same named components as that returned by therpartfunction.- cp
Complexity parameter to which the
rpartobject will be trimmed.- ...
further arguments passed to or from other methods.