Skip to contents

Creates a model matrix from a call to rpart.

Usage

rpart.matrix(frame)

Arguments

frame

model frame (from call to rpart)

Value

Returns a matrix from the frame of class matrix. Used internally by the function rpart.