Update an rpart object
rpconvert.RdRpart objects changed (slightly) in their internal format in order to accomdate the changes for user-written split functions. This routine updates an old object to the new format.
rpconvert.RdRpart objects changed (slightly) in their internal format in order to accomdate the changes for user-written split functions. This routine updates an old object to the new format.