rpart.matrix.Rd
Creates a model matrix from a call to rpart.
rpart
rpart.matrix(frame)
model frame (from call to rpart)
Returns a matrix from the frame of class matrix. Used internally by the function rpart.
matrix